@@ -71,13 +71,6 @@ class ScriptRunner(scripts.BaseRunner):
             )
 
 
-@click.command(help="Update docker images")
-@click.pass_obj
-def pullimages(context):
-    config = tutor_config.load(context.root)
-    context.docker_compose(context.root, config, "pull")
-
-
 @click.command(help="Run all or a selection of configured Open edX services")
 @click.option("-d", "--detach", is_flag=True, help="Start in daemon mode")
 @click.argument("services", metavar="service", nargs=-1)
@@ -136,34 +129,6 @@ def restart(context, services):
     context.docker_compose(context.root, config, *command)
 
 
-@click.command(
-    short_help="Run a command in a new container",
-    help="This is a wrapper around `docker-compose run`. Any option or argument passed to this command will be forwarded to docker-compose. Thus, you may use `-v` or `-p` to mount volumes and expose ports.",
-    context_settings={"ignore_unknown_options": True},
-)
-@click.argument("args", nargs=-1, required=True)
-@click.pass_obj
-def run(context, args):
-    config = tutor_config.load(context.root)
-    command = ["run", "--rm"]
-    if not utils.is_a_tty():
-        command.append("-T")
-    context.docker_compose(context.root, config, *command, *args)
-
-
-@click.command(
-    short_help="Run a command in a running container",
-    help="This is a wrapper around `docker-compose exec`. Any option or argument passed to this command will be forwarded to docker-compose. Thus, you may use `-e` to manually define environment variables.",
-    context_settings={"ignore_unknown_options": True},
-    name="exec",
-)
-@click.argument("args", nargs=-1, required=True)
-@click.pass_obj
-def execute(context, args):
-    config = tutor_config.load(context.root)
-    context.docker_compose(context.root, config, "exec", *args)
-
-
 @click.command(help="Initialise all applications")
 @click.option("-l", "--limit", help="Limit initialisation to this service or plugin")
 @click.pass_obj
@@ -173,44 +138,6 @@ def init(context, limit):
     scripts.initialise(runner, limit_to=limit)
 
 
-@click.command(
-    short_help="Manually trigger hook (advanced users only)",
-    help="""
-Manually trigger a hook for a given plugin/service. This is a low-level command
-that is convenient when developing new plugins. Ex:
-
-    tutor local hook mysql hooks mysql init
-    tutor local hook discovery discovery hooks discovery init""",
-    name="hook",
-)
-@click.argument("service")
-@click.argument("path", nargs=-1)
-@click.pass_obj
-def run_hook(context, service, path):
-    config = tutor_config.load(context.root)
-    runner = ScriptRunner(context.root, config, context.docker_compose)
-    fmt.echo_info(
-        "Running '{}' hook in '{}' container...".format(".".join(path), service)
-    )
-    runner.run_job_from_template(service, *path)
-
-
-@click.command(help="View output from containers")
-@click.option("-f", "--follow", is_flag=True, help="Follow log output")
-@click.option("--tail", type=int, help="Number of lines to show from each container")
-@click.argument("service", nargs=-1)
-@click.pass_obj
-def logs(context, follow, tail, service):
-    command = ["logs"]
-    if follow:
-        command += ["--follow"]
-    if tail is not None:
-        command += ["--tail", str(tail)]
-    command += service
-    config = tutor_config.load(context.root)
-    context.docker_compose(context.root, config, *command)
-
-
 @click.command(help="Create an Open edX user and interactively set their password")
 @click.option("--superuser", is_flag=True, help="Make superuser")
 @click.option("--staff", is_flag=True, help="Make staff user")
@@ -253,17 +180,81 @@ def importdemocourse(context):
     scripts.import_demo_course(runner)
 
 
+@click.command(
+    short_help="Direct interface to docker-compose.",
+    help=(
+        "Direct interface to docker-compose. This is a wrapper around `docker-compose`. All commands, options and"
+        " arguments passed to this command will be forwarded to docker-compose."
+    ),
+    context_settings={"ignore_unknown_options": True},
+    name="dc",
+)
+@click.argument("args", nargs=-1, required=True)
+@click.pass_obj
+def dc_command(context, args):
+    config = tutor_config.load(context.root)
+    context.docker_compose(context.root, config, *args)
+
+
+@click.command(
+    short_help="Run a command in a new container",
+    help=(
+        "Run a command in a new container. This is a wrapper around `docker-compose run`. Any option or argument passed"
+        " to this command will be forwarded to docker-compose. Thus, you may use `-v` or `-p` to mount volumes and"
+        " expose ports."
+    ),
+    context_settings={"ignore_unknown_options": True},
+)
+@click.argument("args", nargs=-1, required=True)
+def run(args):
+    command = ["run", "--rm"]
+    if not utils.is_a_tty():
+        command.append("-T")
+    dc_command.callback([*command, *args])
+
+
+@click.command(
+    short_help="Run a command in a running container",
+    help=(
+        "Run a command in a running container. This is a wrapper around `docker-compose exec`. Any option or argument"
+        " passed to this command will be forwarded to docker-compose. Thus, you may use `-e` to manually define"
+        " environment variables."
+    ),
+    context_settings={"ignore_unknown_options": True},
+    name="exec",
+)
+@click.argument("args", nargs=-1, required=True)
+def execute(args):
+    dc_command.callback(["exec", *args])
+
+
+@click.command(
+    short_help="View output from containers",
+    help="View output from containers. This is a wrapper around `docker-compose logs`.",
+)
+@click.option("-f", "--follow", is_flag=True, help="Follow log output")
+@click.option("--tail", type=int, help="Number of lines to show from each container")
+@click.argument("service", nargs=-1)
+def logs(follow, tail, service):
+    command = ["logs"]
+    if follow:
+        command += ["--follow"]
+    if tail is not None:
+        command += ["--tail", str(tail)]
+    command += service
+    dc_command.callback(command)
+
+
 def add_commands(command_group):
-    command_group.add_command(pullimages)
     command_group.add_command(start)
     command_group.add_command(stop)
     command_group.add_command(restart)
     command_group.add_command(reboot)
-    command_group.add_command(run)
-    command_group.add_command(execute)
     command_group.add_command(init)
-    command_group.add_command(logs)
     command_group.add_command(createuser)
     command_group.add_command(importdemocourse)
     command_group.add_command(settheme)
-    # command_group.add_command(run_hook) # Disabled for now
+    command_group.add_command(dc_command)
+    command_group.add_command(run)
+    command_group.add_command(execute)
+    command_group.add_command(logs)
